<?php

namespace App\Console\Commands;

use App\Mail\CalibrationExpireMail;
use App\Models\Calibration;
use App\Models\Customer;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Mail;
use Twilio\Rest\Client;

class AutoCalibrationExpireMail extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'auto:calibrationexpiremail';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Send calibration expire mail to customers';

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {

        $calibrations = Calibration::with('customer')->whereMonth('date_of_expiry', date('m'))->whereDay('date_of_expiry', Carbon::now()->subDays(2))->where('expire_mail_status', '>=','pending')->get();
  
        if ($calibrations->count() > 0) 
        {
            foreach ($calibrations as $calibration) 
            {
                // SENDING MAIL
                Mail::to($calibration->email)->send(new CalibrationExpireMail($calibration));

                // TWILIO SMS
                $twilio = new Client(env("TWILIO_SID"), env("TWILIO_TOKEN"));
                $twilio->messages->create($calibration->customer->number, ['from' => env("TWILIO_FROM"), 'body' => "Your Calibration Certifiate Is Going To Expire On ".$calibration->date_of_expiry." Please Renew It Or Contact Microval"]);

                // UPDATING STATUS
                $calibration->expire_mail_status = 'sent';
                $calibration->update();
            }
        }

        return 0;
    }
}
