<?php

namespace App\Http\Controllers;

use App\Http\Requests\CalibrationRequest;
use App\Models\Calibration;
use App\Models\CalibrationCount;
use App\Models\CalibrationLabel;
use App\Models\Customer;
use App\Models\Instrument;
use App\Models\MasterEquipment;
use App\Models\PerformanceQualificationCertificate;
use App\Models\UnitSymbol;
use DataTables;
use Illuminate\Http\Request;
use Auth;

class CalibrationController extends Controller
{
    public function index()
    {
        // $calibrations = Calibration::query();
        // // SEARCH FILTER FOR CUSTOMER
        // if (!empty(request()->customer)) $calibrations->whereHas('customer', function($q){$q->where('id', request()->customer);} );
        // // SEARCH FILTER FOR YEAR
        // if (!empty(request()->year)) $calibrations->whereYear('date_of_issue', request()->year);
        // $calibrations = $calibrations->with('moreReviews', 'customer', 'instrument', 'user')->where('certificate_id', null)->get();
        // return view('page.certificate-of-calibration.certificate-of-calibration', compact('calibrations'));
        if(Auth::user()->can('calibration show')){

            return view('page.certificate-of-calibration.certificate-of-calibration');
        }else{
            abort(401);
        }

    }

    public function indexApi()
    {
        {
            // $newDate = \Carbon\Carbon::createFromFormat('m/d/Y', $date)->format('Y-m-d');

            $dateFrom = \Carbon\Carbon::parse(request()->date_from)->format('Y-m-d');
            $dateTo = \Carbon\Carbon::parse(request()->date_to)->format('Y-m-d');
            $customer_id = request()->company;
            //$calibrations = Calibration::query();
            // SEARCH FILTER FOR CUSTOMER
            //$calibrations = $calibrations->where('customer_id', request()->company);
            //$calibrations = $calibrations->whereDate('date_of_issue', '>=', $dateFrom);
            // $calibrations->whereBetween('date_of_issue', [$dateFrom, $dateto]); 
            // dd($calibrations);
            //dd($customer_id);
            $calibrations = Calibration::with('moreReviews', 'customer', 'instrument', 'user')
                            ->where('customer_id', '=', $customer_id)
                            ->whereDate('date_of_issue', '>=', $dateFrom)
                            ->whereDate('date_of_issue', '<=', $dateTo)
                            ->where('certificate_id', null)->get();

            //dd($calibrations->length());
            return DataTables::of($calibrations)
                    ->addIndexColumn()
                    ->addColumn('checkbox', function($certificate){
                        $checkbox = '<input type="checkbox" name="ids[]" value="'.$certificate->id.'">';
                        return $checkbox;
                    })
                    ->addColumn('customerHref', function($certificate){
                        $customerHref = '<a href="'.route("admin_calibration_index", ["customer" => $certificate->customer->id]).'">'.$certificate->customer->name.'</a>';
                        return $customerHref;
                    })
                    ->addColumn('action', function($certificate){
                         $actionBtn = "
                            <a href='".route('admin_calibration_update', ['id' => $certificate->id])."'
                                class='btn btn-primary'><i class='fas fa-edit'></i></a> |
                            <a title='View PDF'
                                href='".route('pdf_show', ['id' => $certificate->id])."'
                                class='btn btn-info'><i class='fas fa-eye'></i></a> |
                            <a title='Download PDF'
                                href='".route('admin_calibration_pdf_download', ['id' => $certificate->id])."'
                                class='btn btn-primary'><i class='fas fa-download'></i></a> |
                     
                            <a onclick='return confirm('Sure Want To Delete?')'
                                href='".route('admin_calibration_delete', ['id' => $certificate->id])."'
                                class='btn btn-danger'><i class='fas fa-trash'></i></a>
                    ";
                        return $actionBtn;
                    })
                    ->rawColumns(['checkbox', 'customerHref', 'action'])
                    ->make(true);
        }    }

    public function store()
    {                           

        if(Auth::user()->can('calibration create')){

            $masterEquipments = MasterEquipment::where('renewed', 0)->orderBy('master_equipment', 'asc')->get();
            $customers = Customer::all();
            $instruments = Instrument::all();
            $unitSymbols = UnitSymbol::all();
            $labels = CalibrationLabel::doesntHave('calibration')->doesntHave('pqCertificate')->get();
            return view('page.certificate-of-calibration.add', compact('masterEquipments', 'customers', 'instruments', 'unitSymbols', 'labels'));
        }else{
            abort(401);
        }
    }

    public function storeProcess(CalibrationRequest $request)
    {
        // if (isset($request->validator) && $request->validator->fails()) 
        // {
        //     return response()->json($request->validator->errors(), 400);
        // }
        if(Auth::user()->can('calibration create')){

            $request = $request->validated();

            $certificate = new Calibration();
            $certificate->master_equip_id = $request['master_equipment_one'];
            $certificate->master_equip_two_id = request()->master_equipment_two=='Select Master Equipment Two'?(NULL):request()->master_equipment_two;
            $certificate->customer_id = $request['customer'];
            $certificate->instrument_id = $request['instrument_type'];
            // $certificate->address = $request['address'];
            $certificate->date_of_issue = $request['date_of_issue'];
            // $certificate->email = $request['email'];
            $certificate->date_of_expiry = $request['date_of_expiry'];
            $certificate->user_id = $request['user_id'];
            $certificate->sub_location = $request['sub_location'];
            $certificate->location = $request['location'];
            $certificate->model = $request['model'];
            $certificate->make = $request['make'];
            $certificate->range = $request['range'];
            $certificate->range_symbol = $request['rangeSymbol']??'';
            $certificate->accuracy = $request['accuracy'];
            $certificate->accuracy_symbol = $request['accuracySymbol']??'';
            $certificate->serial = $request['serial'];
            $certificate->condition = $request['condition'];
            $certificate->least_count = $request['least_count'];
            $certificate->least_count_symbol = $request['leastSymbol']??'';
            $certificate->tolerance_limit = $request['tolerance_limit'];
            $certificate->tolerance_symbol = $request['toleranceSymbol']??'';
            if($certificate->save())
            {
                $count = CalibrationCount::first();
                if ($count == null) 
                {
                    CalibrationCount::insert(['count' => 1]);
                }
                else
                {
                    $count->update(['count' => $count->count+1]);
                }
                if (count($request['master_reading']) > 0) 
                {
                    for ($i=0; $i < count($request['master_reading']); $i++) 
                    { 
                        if (!empty($request['master_reading'][$i]) || !empty($request['uut_reading'][$i]) || !empty($request['review'][$i]) || !empty($request['mudrSymbol'][$i])) 
                        {
                            $testPerformed = new Calibration();
                            $testPerformed->certificate_id = $certificate->id;
                            $testPerformed->master_reading = $request['master_reading'][$i];
                            $testPerformed->uut_reading = $request['uut_reading'][$i];
                            $testPerformed->difference = $request['difference'][$i];
                            $testPerformed->review = $request['review'][$i];
                            $testPerformed->mudr_symbol = $request['mudrSymbol'][$i]??'';
                            $testPerformed->save();
                        }
                    }
                }
                toastr('Data Stored', 'success');
                return redirect()->route('admin_calibration_index');
                // return redirect()->route('pdf_show', ['id' => $certificate->id]);
            }
        }else{
            abort(401);
        }
    }

    public function update($id)
    {
        if(Auth::user()->can('calibration edit')){

            $certificate = Calibration::with('moreReviews', 'user')->find($id);
            $masterEquipments = MasterEquipment::where('renewed', 0)->orderBy('master_equipment', 'asc')->get();
            // $existingMasterEquipments = MasterEquipment::find($certificate->master_equip_id);
            // $masterEquipments->push($existingMasterEquipments);
            $customers = Customer::all();
            $instruments = Instrument::all();
            $unitSymbols = UnitSymbol::all();
            $existingLabels = Calibration::where('user_id', '!=', $certificate->user->id)->pluck('user_id');
            $pqCertificateLabels = PerformanceQualificationCertificate::where('user_id', '!=', null)->pluck('user_id');
            $existingLabels = $existingLabels->merge($pqCertificateLabels);
            $labels = CalibrationLabel::whereNotIn('id', $existingLabels)->get();

            return view('page.certificate-of-calibration.edit', compact('certificate', 'masterEquipments', 'customers', 'instruments', 'unitSymbols', 'labels'));
        }else{
            abort(401);
        }
    }

    public function updateProcess(CalibrationRequest $request, $id)
    {
        if(Auth::user()->can('calibration edit')){

            $request = $request->validated();

            // dd($request);


            $certificate = Calibration::find($id);
            $certificate->master_equip_id = $request['master_equipment_one'];
            $certificate->master_equip_two_id = request()->master_equipment_two=='Select Master Equipment Two'?(NULL):request()->master_equipment_two;
            $certificate->customer_id = $request['customer'];
            $certificate->instrument_id = $request['instrument_type'];
            // $certificate->address = $request['address'];
            $certificate->date_of_issue = $request['date_of_issue'];
            // $certificate->email = $request['email'];
            $certificate->date_of_expiry = $request['date_of_expiry'];
            $certificate->user_id = $request['user_id'];
            $certificate->sub_location = $request['sub_location'];
            $certificate->location = $request['location'];
            $certificate->model = $request['model'];
            $certificate->make = $request['make'];
            $certificate->range = $request['range'];
            $certificate->range_symbol = $request['rangeSymbol']??'';
            $certificate->accuracy = $request['accuracy'];
            $certificate->accuracy_symbol = $request['accuracySymbol']??'';
            $certificate->serial = $request['serial'];
            $certificate->condition = $request['condition'];
            $certificate->least_count = $request['least_count'];
            $certificate->least_count_symbol = $request['leastSymbol']??'';
            $certificate->tolerance_limit = $request['tolerance_limit'];
            $certificate->tolerance_symbol = $request['toleranceSymbol']??'';
            if($certificate->update())
            {
                if (count($request['master_reading']) > 0) 
                {
                    Calibration::where('certificate_id', $id)->delete();
                    for ($i=0; $i < count($request['master_reading']); $i++) 
                    { 
                        if (!empty($request['master_reading'][$i]) || !empty($request['uut_reading'][$i]) || !empty($request['review'][$i]) || !empty($request['mudrSymbol'][$i])) 
                        {
                            $testPerformed = new Calibration();
                            $testPerformed->certificate_id = $certificate->id;
                            $testPerformed->master_reading = $request['master_reading'][$i];
                            $testPerformed->uut_reading = $request['uut_reading'][$i];
                            $testPerformed->difference = $request['difference'][$i];
                            $testPerformed->review = $request['review'][$i];
                            $testPerformed->mudr_symbol = $request['mudrSymbol'][$i]??'';
                            $testPerformed->save();
                        }
                    }
                }
                toastr('Data Stored', 'success');
                return redirect()->route('admin_calibration_index');
            }
        }else{
            abort(401);
        }
    }

    public function delete($id)
    {
        if(Auth::user()->can('calibration delete')){

            Calibration::destroy($id);
            toastr('Deleted', 'success');
            return back();
        }else{
            abort(401);
        }
    }

    protected function downloadMultiple()
    {
        if(empty(request()->ids))
        {
            toastr('Atleast one id is required', 'warning');
            return back();
        }
        return (new Calibration)->downloadMultiple(request()->ids);
    }

    public function renew($calibrationId)
    {
        $calibration = (new Calibration)->renew($calibrationId);
        if($calibration['status'])
        {
            toastr('Certificate Renewed', 'success');
            return redirect()->route('admin_calibration_update', ['id'=>$calibration['data']->id]);
        }
        toastr($calibration['error'], 'error');
        return back();
    }
}
