<?php

namespace App\Http\Controllers;

use App\Http\Requests\CalibrationSendExpireMail;
use App\Mail\CalibrationExpireMail;
use App\Models\Calibration;
use Carbon\Carbon;
use Illuminate\Support\Facades\Mail;

class CalibrationExpireController extends Controller
{
    protected function index()
    {
        $expires = Calibration::with('customer', 'user')
        ->where('certificate_id', null)
        ->whereBetween('date_of_expiry', [now()->startOfMonth()->format('Y-m-d'), now()->addMonth()->endOfMonth()->format('Y-m-d')])
        ->orWhereDate('date_of_expiry', '<=', now()->format('Y-m-d'))
        ->get();

        // REMOVING RENEWED CERTIFICATES FROM COLLECTION
        $expires = $expires->reject(function($data) {
            return $data->renewed == 1;
        });
        // dd($expires);
        return view('page.calibration-expire.table', compact('expires'));
    }

    protected function email()
    {
        return view('page.calibration-expire.mail');
    }

    protected function sendMail(CalibrationSendExpireMail $request, $id)
    {
        $request = $request->validated();

        try {
            Mail::to($request['to'])->send(new CalibrationExpireMail($request));
            if (!empty($request['file'])) 
            {
                $request['file']->move(public_path('uploads/calibration/expire_attachment/'), $request['file']->getClientOriginalName());
            }
            Calibration::find($id)->update(['expire_mail_status' => 'sent']);
            toastr('Mail Sent', 'success');
            return redirect()->route('admin_calibration_expire_index');
        } catch (\Throwable $th) {
            toastr($th->getMessage(), 'error');
            return back()->withInput(request()->all());
        }

    }
}
