<?php

namespace App\Http\Controllers;

use App\Exports\CalibrationLabelExport;
use App\Models\CalibrationLabel;
use App\Http\Requests\StoreCalibrationLabelRequest;
use App\Http\Requests\UpdateCalibrationLabelRequest;
use Maatwebsite\Excel\Facades\Excel;
use Auth;

class CalibrationLabelController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->can('basicoperation show')){

            $labels = CalibrationLabel::all();
            return view('page.Tag.table', compact('labels'));
        }else{
            abort(401);
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('page.Tag.add');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreCalibrationLabelRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreCalibrationLabelRequest $request)
    {
        $response = (new CalibrationLabel())->store($request->validated());
        if($response['status']===false) 
        {
            toastr($response['error'], 'error');
            return back()->withInput();
        }
        toastr('Label Added', 'success', 'Success');
        return redirect()->route('label.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\CalibrationLabel  $calibrationLabel
     * @return \Illuminate\Http\Response
     */
    public function show(CalibrationLabel $calibrationLabel)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\CalibrationLabel  $calibrationLabel
     * @return \Illuminate\Http\Response
     */
    public function edit(CalibrationLabel $calibrationLabel)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateCalibrationLabelRequest  $request
     * @param  \App\Models\CalibrationLabel  $calibrationLabel
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateCalibrationLabelRequest $request, CalibrationLabel $calibrationLabel)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\CalibrationLabel  $calibrationLabel
     * @return \Illuminate\Http\Response
     */
    public function destroy($label)
    {
        CalibrationLabel::destroy($label);
        toastr('Record Destroyed', 'success', 'Success');
        return back();
    }

    public function delete($label)
    {
        CalibrationLabel::destroy($label);
        toastr('Record Destroyed', 'success', 'Success');
        return back();
    }

    protected function export()
    {
        return Excel::download(new CalibrationLabelExport(), 'Labels.xlsx');
    }
}
