<?php

namespace App\Http\Controllers;

use App\Models\Customer;
use App\Http\Requests\StoreCustomerRequest;
use App\Http\Requests\UpdateCustomerRequest;
use Auth;

class CustomerController extends Controller
{
    public function index()
    {
        if(Auth::user()->can('basicoperation show')){

            $customers = Customer::all();
            return view('page.customer.customer', compact('customers'));
        }else{
            abort(401);
        }
    }

    public function store()
    {
        return view('page.customer.add');
    }

    public function storeProcess(StoreCustomerRequest $request)
    {
        $request = $request->validated();

        $validate = Customer::where('name', $request['name'])->exists();

        if ($validate) {
            toastr('User Name Already Exists', 'warning');
            return back()->withInput($request);
        }

        $customer = new Customer();
        $customer->name = $request['name'];
        $customer->representative_name = $request['representative_name'];
        $customer->email = $request['email'];
        $customer->number = $request['number'];
        $customer->address = $request['address'];
        if($customer->save())
        {
            toastr('Data Stored', 'success');
            return redirect()->route('admin_customer_index');
        }
    }

    public function update($id)
    {
        $customer = Customer::find($id);
        return view('page.customer.edit', compact('customer'));
    }

    public function updateProcess(UpdateCustomerRequest $request, $id)
    {
        $request = $request->validated();

        $validate = Customer::where('name', $request['name'])->where('id', '!=', $id)->exists();

        if ($validate) {
            toastr('User Name Already Exists', 'warning');
            return back()->withInput($request);
        }

        $customer = Customer::find($id);
        $customer->name = $request['name'];
        $customer->representative_name = $request['representative_name'];
        $customer->email = $request['email'];
        $customer->number = $request['number'];
        $customer->address = $request['address'];
        if($customer->update())
        {
            toastr('Data Updated', 'success');
            return redirect()->route('admin_customer_index');
        }
    }

    public function delete($id)
    {
        Customer::destroy($id);
        toastr('Deleted', 'success');
        return back();
    }

    public function show()
    {
        $customer = Customer::find(request()->id);
        return response()->json($customer, 200);
    }
}
