<?php

namespace App\Http\Controllers;

use App\Http\Requests\MasterEquipmentRequest;
use App\Models\MasterEquipment;
use App\Models\UnitSymbol;
use Auth;


class MasterEquipmentController extends Controller
{
    public function index()
    {
        if(Auth::user()->can('master show')){
            $masterEquipments = MasterEquipment::query();
            if (!empty(request()->year)) $masterEquipments->whereYear('cal_due_date', request()->year);
            $masterEquipments = $masterEquipments->get();
            return view('page.master-testing.models', compact('masterEquipments'));
        }else{
            abort(401);
        }
    }

    public function store()
    {
        if(Auth::user()->can('master create')){

            $unitSymbols = UnitSymbol::all();
            return view('page.master-testing.add', compact('unitSymbols'));
        }else{
            abort(401);
        }
    }

    public function storeProcess(MasterEquipmentRequest $request)
    {
        if(Auth::user()->can('master create')){

            $request = $request->validated();

            $masterEquipment = new MasterEquipment();
            $masterEquipment->master_equipment = $request['master_equipment'];
            $masterEquipment->model = $request['model'];
            $masterEquipment->serial_no = $request['serial_no'];
            $masterEquipment->range = $request['range'];
            $masterEquipment->range_symbol = $request['rangeSymbol']??'';
            $masterEquipment->accuracy = $request['accuracy'];
            $masterEquipment->accuracy_symbol = $request['accuracySymbol']??'';
            $masterEquipment->traceability_ref_no = $request['traceability_ref_no']??'';
            $masterEquipment->traceability_symbol = $request['traceabilitySymbol']??'';
            $masterEquipment->cal_due_date = $request['cal_due_date'];
            if($masterEquipment->save())
            {
                toastr('Data Stored', 'success');
                return redirect()->route('admin_master_equipment_index');
            }
        }else{
            abort(401);
        }
    }

    public function update($id)
    {
        if(Auth::user()->can('master edit')){

            $masterEquipment = MasterEquipment::find($id);
            $unitSymbols = UnitSymbol::all();
            return view('page.master-testing.edit', compact('masterEquipment', 'unitSymbols'));
        }else{
            abort(401);
        }
    }

    public function updateProcess(MasterEquipmentRequest $request, $id)
    {
        if(Auth::user()->can('master edit')){

            $request = $request->validated();

            $masterEquipment = MasterEquipment::find($id);
            $masterEquipment->master_equipment = $request['master_equipment'];
            $masterEquipment->model = $request['model'];
            $masterEquipment->serial_no = $request['serial_no'];
            $masterEquipment->range = $request['range'];
            $masterEquipment->range_symbol = $request['rangeSymbol']??'';
            $masterEquipment->accuracy = $request['accuracy'];
            $masterEquipment->accuracy_symbol = $request['accuracySymbol']??'';
            $masterEquipment->traceability_ref_no = $request['traceability_ref_no']??'';
            $masterEquipment->traceability_symbol = $request['traceabilitySymbol']??'';
            $masterEquipment->cal_due_date = $request['cal_due_date'];
            if($masterEquipment->update())
            {
                toastr('Data Updated', 'success');
                return redirect()->route('admin_master_equipment_index');
            }
        }else{
            abort(401);
        }
    }

    public function delete($id)
    {
        if(Auth::user()->can('master delete')){

            MasterEquipment::destroy($id);
            toastr('Deleted', 'success');
            return back();
        }else{
            abort(401);
        }
    }
}
