<?php

namespace App\Http\Controllers;

use App\Models\{QrCode,CalibrationLabel};
use Illuminate\Http\Request;
use SimpleSoftwareIO\QrCode\Facades\QrCode as Code; 

class NewQrCodeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     * 
     * 
     */

    //  public function index()
    //  {
    //    return view('page.qrcode.qrcode');
    //  }
     public function generate(Request $request)
     {
         $time = time();
 
         $request->validate([
             'calibration_date' => 'required|date',
             'recalibration_date' => 'required|date',
             'equipment_name' => 'required',
             'serial_number' => 'required',
             'url' => 'required|url',
         ]);
 
         // Get the input data
         $calibrationDate = $request->input('calibration_date');
         $recalibrationDate = $request->input('recalibration_date');
         $equipmentName = $request->input('equipment_name');
         $serialNumber = $request->input('serial_number');
         $url = $request->input('url');
 
         // create a folder
         if(!\File::exists(public_path('images'))) {
             \File::makeDirectory(public_path('images'), $mode = 0777, true, true);
         }
 
         Code::generate($request->url, 'images/'.$time.'.svg');
 
         $img_url = 'images/'.$time.'.svg';
 
         \Session::put('qrImage', $img_url);
 
         $view = view('page.qrcode.printable', compact('calibrationDate', 'recalibrationDate', 'equipmentName', 'serialNumber'));
         return response($view)->header('Content-Type', 'text/html');
         // return redirect()->route('qrcode');
     }



    public function index()
    {
        $perPage = 100; // Number of items per page
        $qrs = QrCode::paginate($perPage);
        $query="";
        return view('page.qrcode.list',compact('qrs','query'));
    }

    public function search(Request $request)
    {
        //dd(3);
        $perPage = 100;
        $query = $request->get('search');
        // $qrs = QRCode::where('serial_number', 'LIKE', "%{$query}%")
        //              ->orWhere('calibration_date', 'LIKE', "%{$query}%")
        //              ->orWhere('recalibration_date', 'LIKE', "%{$query}%")
        //              ->paginate($perPage);

        $qrs = QRCode::query();
       if(preg_match('/\d{4}-\d{2}-\d{2}/', $query)) {
            $qrs->where(function($q) use ($query) {
                $q->where('calibration_date',  $query )
                  ->orWhere('recalibration_date', $query );
            });
        }else{
             $qrs->where('serial_number', $query);
         } 
        $qrs = $qrs->get();          
        return view('page.qrcode.list',compact('qrs','query'));

        //return response()->json($qrs);
    }
    
    public function multiQrDelete(Request $request)
    {
        // dd($request->all());
        foreach ($request->id as $id){
            //echo $id,"==";
            QRCode::where('id', $id)->delete();
        }
        return redirect()->back()->with('success', 'Successfully Delete.');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $labels = CalibrationLabel::doesntHave('qr_code_jawad')->get();
        return view('page.qrcode.create',compact('labels'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
            
        $request->validate([
            'label_id' => 'required',
            'calibration_date' => 'required|date',
            'recalibration_date' => 'required|date',
            'equipment_name' => 'required',
            'serial_number' => 'required',
           
        ]);


        QrCode::create($request->all());

        return redirect()->route('qrcode.index')->with('success','Form Submitted Successfully!');

    }
    catch(\Exception $e){
        dd($e);
    }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $time = time();
 
        $qr=QrCode::find($id);

        // Get the input data
        $calibrationDate = $qr->calibration_date ?? "null";
        $recalibrationDate = $qr->recalibration_date ?? "null";
        $equipmentName = $qr->equipment_name ?? "null";
        $serialNumber = $qr->serial_number ?? "null";
        $url = isset($qr->label) ? \URL::to('/').'/pdf/show_by_label/'.$qr->label->id : 'null';

        

        // create a folder
        if(!\File::exists(public_path('images'))) {
            \File::makeDirectory(public_path('images'), $mode = 0777, true, true);
        }

        Code::generate($url, 'images/'.$time.'.svg');

        $img_url = 'images/'.$time.'.svg';

        \Session::put('qrImage', $img_url);

        $view = view('page.qrcode.printable', compact('calibrationDate', 'recalibrationDate', 'equipmentName', 'serialNumber'));
        return response($view)->header('Content-Type', 'text/html');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $labels=CalibrationLabel::all();
        $qr=QrCode::find($id);
        return view('page.qrcode.edit',compact('labels','qr'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        try{
            $request->validate([
                'label_id' => 'required',
                'calibration_date' => 'required|date',
                'recalibration_date' => 'required|date',
                'equipment_name' => 'required',
                'serial_number' => 'required',
               
            ]);
    
    
            QrCode::find($id)->update($request->all());
    
            return redirect()->route('qrcode.index')->with('success','Form Submitted Successfully!');
    
        }
        catch(\Exception $e){
            dd($e);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete($id)
    {
       // dd(3);
      
        try{

        QrCode::find($id)->delete();

        return back()->with('success','Deleted Successfully!');

    }
    catch(\Exception $e){
        dd($e);
    }
    }

    public function renew($id){
        try{
        $labels=CalibrationLabel::all();
        $qr=QrCode::find($id);
        return view('page.qrcode.renew',compact('labels','qr'));


        }
            catch(\Exception $e){
                dd($e);
            }
    }


    public function expire(){
        try{
        // $labels=CalibrationLabel::all();
        $qrs=QrCode::with('Label')->where('recalibration_date','<',date('Y-m-d H:i:s'))->get();
        $view=view('page.qrcode.ajax-list',compact('qrs'))->render();
          return $view;  


        }
            catch(\Exception $e){
                dd($e);
            }
    }
    
    public function get_dates()
    {
        $qr_dates = QrCode::where('label_id','=',request()->id)->orderBy('created_at', 'DESC')->first();
        return response()->json($qr_dates, 200);
    }
}
