<?php

namespace App\Http\Controllers;

use App\Models\Note;
use App\Models\NoteFile;
use App\Models\NoteTime;
use App\Models\Recording;
use Auth;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Illuminate\Support\Facades\Storage;

class NotesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->can('note show')){
            $userId = Auth::user()->id;

            Note::where('user_id', $userId)->where('expireNote', 0)->where('created_at', '<=', now()->subDays(2))->update(['expireNote' => 1]); 

            $noteTime=Null;
            $notes=[];
            if(Auth::user()->can('note allnotes')){
                $notes=Note::with('notefiles','user','recordings')->get();
                $noteTime=NoteTime::first();

            }
            if(Auth::user()->can('note ownnotes')){

                $notes = Note::with('notefiles', 'user','recordings')
                
                    ->where('user_id', $userId)
                    // ->where('expireNote', 0) 
                    ->get();

            }
            return view('page.note.list',compact('notes','noteTime'));
        }else{
            abort(401);
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->can('note create')){
            // if(Auth::user()->user_type == 'admin'){
            //     $notes=Note::with('notefiles','user')->get();
            // }else{
            //     $notes=Note::with('notefiles','user')->where('user_id',Auth::user()->id)->get();
            // }
            return view('page.note.create');
        }else{
            abort(401);
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $currentHour = Carbon::now()->hour; // Get the current hour in 24-hour format
      
        

        //dd($request->all());
        // Save to database if needed
        // Recording::create(['name' => $name, 'file_path' => $filePath]);



        $noteTime=NoteTime::first();

        if ($currentHour < $noteTime->start || $currentHour >= $noteTime->end) {
            return redirect()->route('note.index')->with('error', 'Notes can only be created between 11 AM and 7 PM.');
        }
      
        $data=[
            'note'=>$request->note,
            'user_id'=>Auth::user()->id,
            'voice_note'=>$request->audio,
        ];

        $note=Note::create($data);

        $recordings = $request->input('recordings');
        if(isset($recordings)){
            foreach ($recordings as $recording) {
                $name = $recording['name'];
                $audioData = $recording['audio'];
        
                // Decode the Base64 audio data
                list(, $audioBase64) = explode(',', $audioData);
                $audioBinary = base64_decode($audioBase64);
            
                // Generate a unique file name
                $fileName = uniqid() . '.webm';
        
                // Save the audio file
               // Define the full path in the public/recordings directory
                $filePath = 'recordings/' . $fileName;
                $fullPath = public_path($filePath);
    
                // Ensure the recordings directory exists
                if (!file_exists(public_path('recordings'))) {
                    mkdir(public_path('recordings'), 0777, true);
                }
    
                // Save the audio file in the public directory
                file_put_contents($fullPath, $audioBinary);
    
        
                // Save to database if needed
                Recording::create(['name' => $name, 'file_path' => $filePath,'note_id'=>$note->id]);
            }
        }
       
    


        if ($request->hasFile('filespdf')) {

            foreach ($request->file('filespdf') as $key => $image) {
                // Move the file first
                //dd(3);
                $imagename = time() . '_' . $image->getClientOriginalName();
                $uploadPath = public_path('note');
                $image->move($uploadPath, $imagename);
                // Get the file size from the new location
                
                $imagedata = [
                    'files' => asset('note/' . $imagename),
                    'note_id' => $note->id, // Use the image_name from the array
                ];// Add the file size to the array
        
                NoteFile::create($imagedata);
            }
        }

        return redirect()->route('note.index')->with('success', 'Note successfully created.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->can('note edit')){

            $notes=Note::with('notefiles','user')->where('id',$id)->first();
            return view('page.note.edit',compact('notes'));


        }else{
            abort(401);
        }

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //dd($request->all());
        $data=[
            'note'=>$request->note,
        ];
        if($request->audio){
            $data['voice_note']=$request->audio;
        }

        Note::where('id',$id)->update($data);

        $recordings = $request->input('recordings');
        if(isset($recordings)){

            foreach ($recordings as $recording) {
                $name = $recording['name'];
                $audioData = $recording['audio'];
        
                // Decode the Base64 audio data
                list(, $audioBase64) = explode(',', $audioData);
                $audioBinary = base64_decode($audioBase64);
            
                // Generate a unique file name
                $fileName = uniqid() . '.webm';
        
                // Save the audio file
            // Define the full path in the public/recordings directory
                $filePath = 'recordings/' . $fileName;
                $fullPath = public_path($filePath);

                // Ensure the recordings directory exists
                if (!file_exists(public_path('recordings'))) {
                    mkdir(public_path('recordings'), 0777, true);
                }

                // Save the audio file in the public directory
                file_put_contents($fullPath, $audioBinary);

        
                // Save to database if needed
                Recording::create(['name' => $name, 'file_path' => $filePath,'note_id'=>$id]);
            }
        }




        if ($request->hasFile('filespdf')) {
            //dd(2);
            foreach ($request->file('filespdf') as $key => $image) {
                //dd(2);
                // Move the file first
                $imagename = time() . '_' . $image->getClientOriginalName();
                $uploadPath = public_path('note');
                $image->move($uploadPath, $imagename);
                // Get the file size from the new location
                
               
                $imagedata = [
                    'files' => asset('note/' . $imagename),
                    'note_id' => $id, // Use the image_name from the array
                ];// Add the file size to the array
        
                NoteFile::create($imagedata);
            }
        }

        return redirect()->route('note.index')->with('success', 'Note successfully created.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {   
        //dd(3);
        if(Auth::user()->can('note delete')){
            NoteFile::where('note_id',$id)->delete();
            Note::where('id',$id)->delete();
            return redirect()->route('note.index')->with('success', 'Note successfully Delete.');

        }else{
            abort(401);
        }

    }


    public function updateTime(Request $request){
        $data=[
            'start'=>$request->start,
            'end'=>$request->end,
        ];
        NoteTime::updateOrCreate(
            ['id' => 1], // Match condition
            ['start' => $request->start, 'end' => $request->end]
        );
        return redirect()->route('note.index')->with('success', 'Note Time successfully update.');

    }

    public function filedelete($id){
        
        NoteFile::where('id',$id)->delete();
        return redirect()->back()->with('success', 'File Delete Successfully.');

    }


    public function audiodelete($id){
        
        Recording::where('id',$id)->delete();
        return redirect()->back()->with('success', 'File Delete Successfully.');

    }


}
