<?php

namespace App\Http\Controllers;

use App\Models\Calibration;
use App\Models\PerformanceQualificationCertificate;
use PDF;

class PdfController extends Controller
{
    // CERTIFICATE OF CALIBRATION

    public function show($id)
    {
        $certificate = Calibration::with('masterEquipmentOne', 'masterEquipmentTwo', 'moreReviews', 'customer', 'instrument')->findOrFail($id);
        $qrcode = base64_encode(\QrCode::format('svg')->size(75)->errorCorrection('H')->generate(route('pdf_show', ['id' => $id])));
        return PDF::loadView('pdf.testing-pdf', compact('certificate', 'qrcode'))->stream();
    }

    public function showByLabel($label)
    {
        $certificate = Calibration::with('masterEquipmentOne', 'masterEquipmentTwo', 'moreReviews', 'customer', 'instrument')->where('user_id',$label)->orderBy('id', 'desc');
        $pqCertificate = PerformanceQualificationCertificate::where('user_id',$label);
        if($certificate->exists()) return $this->show($certificate->first()->id);
        if($pqCertificate->exists()) return $this->performanceQualificationCertificatePdf($pqCertificate->first()->id);
        toastr('No Certificate Assigned Yet', 'error');
        return redirect()->route('label.index');
    }
    
    public function downloadPDF($id)
    {
        $certificate = Calibration::with('masterEquipmentOne', 'masterEquipmentTwo', 'moreReviews', 'customer', 'instrument', 'user')->findOrFail($id);
        $qrcode = base64_encode(\QrCode::format('svg')->size(75)->errorCorrection('H')->generate(route('pdf_show', ['id' => $id])));
        return PDF::loadView('pdf.testing-pdf', compact('certificate', 'qrcode'))->download($certificate->user->label_id.'.pdf');
    }

    // PERFORMANCE QUALIFICATION CERTIFICATE
    public function performanceQualificationCertificatePdf($id)
    {
        $performanceQualityCertificate = PerformanceQualificationCertificate::find($id);
        $qrcode = base64_encode(\QrCode::format('svg')->size(75)->errorCorrection('H')->generate(route('admin_pdf_performance_qualification_certificate', ['id' => $id])));
        return PDF::loadView('pdf.master-testing-pdf', compact('performanceQualityCertificate', 'qrcode'))->stream();
    }

    public function performanceQualificationCertificatePdfDownload($id)
    {
        $performanceQualityCertificate = PerformanceQualificationCertificate::with('user')->find($id);
        $qrcode = base64_encode(\QrCode::format('svg')->size(75)->errorCorrection('H')->generate(route('admin_pdf_performance_qualification_certificate', ['id' => $id])));
        return PDF::loadView('pdf.master-testing-pdf', compact('performanceQualityCertificate', 'qrcode'))->download($performanceQualityCertificate->user->label_id.'.pdf');
    }

    // LABEL
    public function label($id)
    {
        $customPaper = array(0,0,144,72);
        $label = Calibration::with('masterEquipmentOne', 'masterEquipmentTwo', 'moreReviews', 'customer', 'instrument')->findOrFail($id);
        $qrcode = base64_encode(\QrCode::format('svg')->size(75)->errorCorrection('H')->generate(route('pdf_show', ['id' => $id])));
        return PDF::loadView('pdf.label', compact('label', 'qrcode'))->setPaper($customPaper, 'portrait')->stream();
    }
}
