<?php

namespace App\Http\Controllers;

use App\Models\PerformanceQualificationCertificate;
use App\Http\Requests\StorePerformanceQualificationCertificateRequest;
use App\Http\Requests\UpdatePerformanceQualificationCertificateRequest;
use App\Models\Calibration;
use App\Models\CalibrationLabel;
use Auth;

class PerformanceQualificationCertificateController extends Controller
{
    public function index()
    {
        if(Auth::user()->can('validation show')){

            $performanceQualityCertificate = PerformanceQualificationCertificate::query();
            if (!empty(request()->year)) $performanceQualityCertificate->whereYear('next_due_date', request()->year);
            $performanceQualityCertificate = $performanceQualityCertificate->with('user')->get();
            
            return view('page.performance-qualification-certificate.performance-qualification-certificate', compact('performanceQualityCertificate'));
        }else{
            abort(401);
        }

    }

    public function store()
    {
        if(Auth::user()->can('validation create')){

            $labels = CalibrationLabel::doesntHave('calibration')->doesntHave('pqCertificate')->get();
            return view('page.performance-qualification-certificate.add', compact('labels'));
        }else{
            abort(401);
        }
    }

    public function storeProcess(StorePerformanceQualificationCertificateRequest $request)
    {
        if(Auth::user()->can('validation create')){

            $request = $request->validated();

            $performanceQualityCertificate = new PerformanceQualificationCertificate();
            $performanceQualityCertificate->user_id = $request['user_id'];
            $performanceQualityCertificate->performance_qualification_protocol_no = $request['performance_qualification_protocol_no'];
            $performanceQualityCertificate->equipment_id = $request['equipment_id'];
            $performanceQualityCertificate->equipment_system_utility = $request['equipment_system_utility'];
            $performanceQualityCertificate->use_purpose = $request['use_purpose'];
            $performanceQualityCertificate->make_model = $request['make_model'];
            $performanceQualityCertificate->location = $request['location'];
            $performanceQualityCertificate->name_of_test = $request['name_of_test'];
            $performanceQualityCertificate->performance_qualification_test_date = $request['performance_qualification_test_date'];
            $performanceQualityCertificate->next_due_date = $request['next_due_date'];
            $performanceQualityCertificate->validated_by = $request['validated_by'];
            // $performanceQualityCertificate->signature = $request['signature'];
            if($performanceQualityCertificate->save())
            {
                toastr('Data Stored', 'success');
                return redirect()->route('admin_pdf_performance_qualification_certificate', ['id' => $performanceQualityCertificate->id]);
            }
        }else{
            abort(401);
        }
    }

    public function update($id)
    {
        if(Auth::user()->can('validation edit')){

            $performanceQualityCertificate = PerformanceQualificationCertificate::find($id);
            $existingLabels = PerformanceQualificationCertificate::where('user_id', '!=', $performanceQualityCertificate->user->id)->pluck('user_id');
            $calibrationLabels = Calibration::where('user_id', '!=', null)->pluck('user_id');
            $existingLabels = $existingLabels->merge($calibrationLabels);
            $labels = CalibrationLabel::whereNotIn('id', $existingLabels)->get();
            return view('page.performance-qualification-certificate.edit', compact('performanceQualityCertificate', 'labels'));
        }else{
            abort(401);
        }
    }

    public function updateProcess(UpdatePerformanceQualificationCertificateRequest $request, $id)
    {
        if(Auth::user()->can('validation edit')){

            $request = $request->validated();

            $performanceQualityCertificate = PerformanceQualificationCertificate::find($id);
            $performanceQualityCertificate->user_id = $request['user_id'];
            $performanceQualityCertificate->performance_qualification_protocol_no = $request['performance_qualification_protocol_no'];
            $performanceQualityCertificate->equipment_id = $request['equipment_id'];
            $performanceQualityCertificate->equipment_system_utility = $request['equipment_system_utility'];
            $performanceQualityCertificate->use_purpose = $request['use_purpose'];
            $performanceQualityCertificate->make_model = $request['make_model'];
            $performanceQualityCertificate->location = $request['location'];
            $performanceQualityCertificate->name_of_test = $request['name_of_test'];
            $performanceQualityCertificate->performance_qualification_test_date = $request['performance_qualification_test_date'];
            $performanceQualityCertificate->next_due_date = $request['next_due_date'];
            $performanceQualityCertificate->validated_by = $request['validated_by'];
            // $performanceQualityCertificate->signature = $request['signature'];
            if($performanceQualityCertificate->update())
            {
                toastr('Data Updated', 'success');
                return redirect()->route('admin_performance_quality_certificate_index');
            }
        }else{
            abort(401);
        }
    }

    public function delete($id)
    {
        if(Auth::user()->can('validation delete')){

            PerformanceQualificationCertificate::destroy($id);
            toastr('Deleted', 'success');
            return back();
        }else{
            abort(401);
        }
    }
}
