<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Auth;
use App\Models\Admin;
use App\Models\Role;
use Illuminate\Support\Facades\Hash;


class UserController extends Controller
{
  
    // Display a listing of users
    public function index()
    {
        if(Auth::user()->can('user show')){
            $users =Admin::all();
            return view('page.user.index', compact('users'));
        }else{
            abort(401);
        }
    }

    // Show the form for creating a new user
    public function create()
    {
        if(Auth::user()->can('user show')){
            $role=Role::get();
            return view('page.user.create',compact('role'));
        }else{
            abort(401);
        }
    }

    // Store a newly created user in storage
    public function store(Request $request)
    {
        if(Auth::user()->can('user create')){

            $validatedData = $request->validate([
                'fname' => 'required|string|max:255',
                'lname' => 'required|string|max:255',
                'email' => 'required|email|unique:users,email',
                'password' => 'required|string|min:6',
                'user_type' => 'required|string|max:255',
                'phone' => 'required|string|max:15',
            ]);

            $validatedData['password'] = Hash::make($validatedData['password']);

            $user=Admin::create($validatedData);
            $user->assignRole($request->user_type);
            return redirect()->route('user.index')->with('success', 'User created successfully!');
        }else{
            abort(401);
        }
    }

    // Show the form for editing the specified user
    public function edit(Admin $user)
    {
        if(Auth::user()->can('user edit')){
            $role=Role::get();

        return view('page.user.edit', compact('user','role'));
    }else{
        abort(401);
    }
    }

    // Update the specified user in storage
    public function update(Request $request, Admin $user)
    {
        if(Auth::user()->can('user edit')){
            //dd($request->all());
            $validatedData = $request->validate([
                'fname' => 'required|string|max:255',
                'lname' => 'required|string|max:255',
                'email' => 'required|email|unique:users,email,' . $user->id,
                'password' => 'nullable|string|min:6',
                'user_type' => 'required|string|max:255',
                'phone' => 'required|string|max:15',
            ]);

            if ($request->filled('password')) {
                $validatedData['password'] = Hash::make($validatedData['password']);
            } else {
                unset($validatedData['password']);
            }

            $user->update($validatedData);

            return redirect()->route('user.index')->with('success', 'User updated successfully!');
        }else{
            abort(401);
        }
    }

    // Remove the specified user from storage
    public function destroy(Admin $user)
    {
        if(Auth::user()->can('user delete')){
            $user->delete();
            return redirect()->route('user.index')->with('success', 'User deleted successfully!');
        }else{
            abort(401);
        }
    }


}
