<?php

namespace App\Http\Requests;
use Elegant\Sanitizer\Laravel\SanitizesInput;

use Illuminate\Foundation\Http\FormRequest;

class CalibrationRequest extends FormRequest
{
    use SanitizesInput;

    public $validator = null;
    protected function failedValidation(\Illuminate\Contracts\Validation\Validator $validator)
    {
        $this->validator = $validator;
    }
    
    public function filters()
    {
        return [
            'customer' => 'digit|trim|strip_tags',
            'address' => 'trim|strip_tags',
            'date_of_issue' => 'trim|strip_tags',
            'email' => 'trim|strip_tags',
            'date_of_expiry' => 'trim|strip_tags',
            'user_id' => 'digit|trim|strip_tags',
            'sub_location' => 'trim|strip_tags',
            'location' => 'trim|strip_tags',
            'instrument_type' => 'digit|trim|strip_tags',
            'model' => 'trim|strip_tags',
            'make' => 'trim|strip_tags',
            'range' => 'trim|strip_tags',
            'rangeSymbol' => 'trim|strip_tags',
            'accuracy' => 'trim|strip_tags',
            'accuracySymbol' => 'trim|strip_tags',
            'serial' => 'trim|strip_tags',
            'condition' => 'trim|strip_tags',
            'least_count' => 'trim|strip_tags',
            'leastSymbol' => 'trim|strip_tags',
            'tolerance_limit' => 'trim|strip_tags',
            'toleranceSymbol' => 'trim|strip_tags',
            'master_equipment_one' => 'trim|strip_tags',
            'master_reading' => 'trim|strip_tags',
            'uut_reading' => 'trim|strip_tags',
            'difference' => 'trim|strip_tags',
            'review' => 'trim|strip_tags',
            'mudrSymbol' => 'trim|strip_tags',
        ];
    }
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'customer' => 'required',
            'address' => 'required',
            'date_of_issue' => 'required',
            'email' => 'required',
            'date_of_expiry' => 'required',
            'user_id' => 'required|numeric',
            'sub_location' => 'required',
            'location' => 'required',
            'instrument_type' => 'required',
            'model' => 'required',
            'make' => 'required',
            'range' => 'required',
            'rangeSymbol' => 'max:50',
            'accuracy' => 'required',
            'accuracySymbol' => 'max:50',
            'serial' => 'required',
            'condition' => 'required',
            'least_count' => 'required',
            'leastSymbol' => 'max:50',
            'tolerance_limit' => 'required',
            'toleranceSymbol' => 'required',
            'master_reading' => 'required',
            'uut_reading' => 'required',
            'difference' => 'required',
            'review' => 'required',
            'mudrSymbol' => 'required',
            'master_equipment_one' => 'required',
        ];
    }
}
