<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Elegant\Sanitizer\Laravel\SanitizesInput;

class StoreCustomerRequest extends FormRequest
{

    use SanitizesInput;
    
    public function filters()
    {
        return [
            'name' => 'trim|strip_tags|capitalize',
            'representative_name' => 'trim|strip_tags|capitalize',
            'email' => 'trim|strip_tags',
            'number' => 'digit|trim|strip_tags',
            'address' => 'trim|strip_tags',
        ];
    }
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'name' => 'required',
            'representative_name' => 'required',
            'email' => 'required|unique:customers,email',
            'number' => 'required|unique:customers,number',
            'address' => 'max:120',
        ];
    }
}
