<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Casts\Attribute;
use File;
use PDF;

class Calibration extends Model
{
    use HasFactory;

    protected $guarded = [];

    // QUERIES
    public function downloadMultiple(array $ids)
    {
        // MAKING DIRECTORY TO STORE DOMPDF FILES
        $this->makeDirectory();
        // DELETING AND THEN THEN ADDING SAME FOLDER FOR NEW DATA
        $this->unlinkFolder();
        // STORE PDF
        $this->storePdf($ids);
        // MAKING ZIP
        $zip = $this->makeZip();
        // DOWNLOADING ZIP
        return response()->download(public_path($zip));
    }

    public function SavePdf($id)
    {
        $certificate = Calibration::with('masterEquipmentOne', 'masterEquipmentTwo', 'moreReviews', 'customer', 'instrument', 'user')->findOrFail($id);
        $qrcode = base64_encode(\QrCode::format('svg')->size(75)->errorCorrection('H')->generate(route('pdf_show', ['id' => $id])));
        return PDF::loadView('pdf.testing-pdf', compact('certificate', 'qrcode'))->save('uploads/pdf/calibration/'.str_replace('/','_',$certificate->user->label_id).'.pdf');
    }

    public function makeDirectory()
    {
        if (!file_exists(public_path('uploads'))) File::makeDirectory(public_path('uploads'));
        if (!file_exists(public_path('uploads/pdf'))) File::makeDirectory(public_path('uploads/pdf'));
        if (!file_exists(public_path('uploads/pdf/calibration'))) File::makeDirectory(public_path('uploads/pdf/calibration'));
    }

    public function unlinkFolder()
    {
        File::deleteDirectory(public_path('uploads/pdf/calibration'));
        File::makeDirectory(public_path('uploads/pdf/calibration'));
    }

    public function storePdf(array $ids)
    {
        // SAVING PDF
        foreach($ids as $id) $this->savePdf($id);
    }

    public function makeZip()
    {
        // IF OLD FILE EXISTS THEN DELETE
        if (file_exists(public_path('pdf.zip'))) unlink(public_path('pdf.zip'));
        
        $zip = new \ZipArchive();
        $fileName = 'pdf.zip';
        $file = 'uploads/pdf/calibration/';
        if ($zip->open(public_path($fileName), \ZipArchive::CREATE)== TRUE)
        {
            $files = File::files(public_path($file));
            foreach ($files as $key => $value)
            {
                $relativeName = basename($value);
                $zip->addFile($value, $relativeName);
            }
            $zip->close();
        }
        return $fileName;
    }

    public function renew(int $calibrationId)
    {
        try {
            $calibration = $this->cloneCertificate($calibrationId);
            if ($calibration['status']) 
            {
                // UPDATING USER ID TO NULL TO AVOID DUPLICATIONS
                // $this->find($calibrationId)->update(['user_id' => (NULL)]);
                return ['status' => true, 'data'=>$calibration['data']];
            }
            return ['status'=>false, ['error'=>$calibration]];
        } catch (\Throwable $th) {
            return ['status'=>false, 'error'=>$th->getMessage()];
        }
    }

    public function cloneCertificate($calibrationId)
    {
        $calibration = $this->with('moreReviews')->find($calibrationId);
        
        // MODIFYING DATE
        $expire = Carbon::createFromFormat('d-m-y', $calibration->date_of_expiry);
        $expire = $expire->addYear()->format('Y-m-d');
        // $expire = Carbon::now()->addYear()->format('Y-m-d');

        // CLONING
        try {
            $newCalibration = $this->create(
                [
                    'customer_id'=>$calibration->customer_id,
                    'instrument_id'=>$calibration->instrument_id,
                    'master_equip_id'=>$calibration->master_equip_id,
                    'master_equip_two_id'=>$calibration->master_equip_two_id,
                    'user_id'=>$calibration->user_id,
                    'address'=>$calibration->address,
                    'email'=>$calibration->email,
                    'date_of_issue'=>now(),
                    'date_of_expiry'=>$expire,
                    'sub_location'=>$calibration->sub_location,
                    'location'=>$calibration->location,
                    'model'=>$calibration->model,
                    'make'=>$calibration->make,
                    'range'=>$calibration->range,
                    'range_symbol'=>$calibration->range_symbol,
                    'accuracy'=>$calibration->accuracy,
                    'accuracy_symbol'=>$calibration->accuracy_symbol,
                    'serial'=>$calibration->serial,
                    'condition'=>$calibration->condition,
                    'least_count'=>$calibration->least_count,
                    'least_count_symbol'=>$calibration->least_count_symbol,
                    'tolerance_limit'=>$calibration->tolerance_limit,
                    'tolerance_symbol'=>$calibration->tolerance_symbol,
                    'master_reading'=>$calibration->master_reading,
                    'uut_reading'=>$calibration->uut_reading,
                    'difference'=>$calibration->difference,
                    'review'=>$calibration->review,
                    'mudr_symbol'=>$calibration->mudr_symbol,
                    'expire_mail_status'=>$calibration->expire_mail_status,
                ]);
    
                // CLONING RELATIONS
                if(!$calibration->moreReviews->isEmpty())
                {
                    foreach($calibration->moreReviews as $review)
                    {
                        $this->create(
                            [
                                'certificate_id'=>$newCalibration->id,
                                'customer_id'=>$review->customer_id,
                                'instrument_id'=>$review->instrument_id,
                                'master_equip_id'=>$review->master_equip_id,
                                'master_equip_two_id'=>$review->master_equip_two_id,
                                'user_id'=>$review->user_id,
                                'certificate_no'=>$newCalibration->certificate_no,
                                'address'=>$review->address,
                                'email'=>$review->email,
                                'date_of_issue'=>now(),
                                'date_of_expiry'=>$expire,
                                'sub_location'=>$review->sub_location,
                                'location'=>$review->location,
                                'model'=>$review->model,
                                'make'=>$review->make,
                                'range'=>$review->range,
                                'range_symbol'=>$review->range_symbol,
                                'accuracy'=>$review->accuracy,
                                'accuracy_symbol'=>$review->accuracy_symbol,
                                'serial'=>$review->serial,
                                'condition'=>$review->condition,
                                'least_count'=>$review->least_count,
                                'least_count_symbol'=>$review->least_count_symbol,
                                'tolerance_limit'=>$review->tolerance_limit,
                                'tolerance_symbol'=>$review->tolerance_symbol,
                                'master_reading'=>$review->master_reading,
                                'uut_reading'=>$review->uut_reading,
                                'difference'=>$review->difference,
                                'review'=>$review->review,
                                'mudr_symbol'=>$review->mudr_symbol,
                                'expire_mail_status'=>$review->expire_mail_status,
                            ]);
                    }
                }

                // UPDATING COUNT TABLE
                $count = CalibrationCount::first();
                $count->update(['count' => $count->count+1]);

                // UPDATING RENEWAL STATUS
                $calibration->update(['renewed' => 1]);
            return ['status'=>true, 'data'=>$newCalibration];
        } catch (\Throwable $th) {
            return ['status'=>false, 'error'=>$th->getMessage()];
        }
    }

    // RELATIONS
    public function moreReviews()
    {
        return $this->hasMany(Calibration::class, 'certificate_id');
    }

    public function masterEquipmentOne()
    {
        return $this->belongsTo(MasterEquipment::class, 'master_equip_id', 'id');
    }

    public function masterEquipmentTwo()
    {
        return $this->belongsTo(MasterEquipment::class, 'master_equip_two_id', 'id');
    }

    public function customer()
    {
        return $this->belongsTo(Customer::class, 'customer_id', 'id');
    }

    public function instrument()
    {
        return $this->belongsTo(Instrument::class, 'instrument_id', 'id');
    }

    public function user()
    {
        return $this->belongsTo(CalibrationLabel::class, 'user_id', 'id');
    }

    // ACCESSOR

    protected $appends = ['range_with_unit', 'accuracy_with_unit', 'least_count_with_unit', 'tolerance_limit_with_unit'];

    protected function dateOfIssue(): Attribute
    {
        return Attribute::make(
            get: fn ($value) => Carbon::parse($value)->format('d-m-y'),
        );
    }

    protected function certificateNo(): Attribute
    {
        return Attribute::make(
            get: fn ($value) => str_replace('-','',$value),
        );
    }

    protected function dateOfExpiry(): Attribute
    {
        return Attribute::make(
            get: fn ($value) => Carbon::parse($value)->format('d-m-y'),
        );
    }
    
    protected function getRangeWithUnitAttribute()
    {
        return $this->range.' '.$this->range_symbol;
    }

    protected function getAccuracyWithUnitAttribute()
    {
        return $this->accuracy.' '.$this->accuracy_symbol;
    }

    protected function getLeastCountWithUnitAttribute()
    {
        return $this->least_count.' '.$this->least_count_symbol;
    }

    protected function getToleranceLimitWithUnitAttribute()
    {
        return '± '.$this->tolerance_limit.' '.$this->tolerance_symbol;
    }

}
