<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class MasterEquipment extends Model
{
    use HasFactory;

    protected $appends = ['range_with_unit', 'accuracy_with_unit', 'traceability_with_unit'];
    protected $guarded = [];

    // QUERIES
    public function renew(int $meId)
    {
        try {
            $me = $this->cloneCertificate($meId);
            if ($me['status']) return ['status' => true, 'data'=>$me['data']];
            return ['status'=>false, ['error'=>$me]];
        } catch (\Throwable $th) {
            return ['status'=>false, 'error'=>$th->getMessage()];
        }
    }

    public function cloneCertificate($meId)
    {
        $me = $this->find($meId);
        
        // MODIFYING DATE
        $expire = Carbon::createFromFormat('Y-m-d', $me->cal_due_date);
        $expire = $expire->addYear()->format('Y-m-d');

        // CLONING
        try {
            $newMe = $this->create(
                [
                    'master_equipment'=>$me->master_equipment,
                    'model'=>$me->model,
                    'serial_no'=>$me->serial_no,
                    'range'=>$me->range,
                    'range_symbol'=>$me->range_symbol,
                    'accuracy'=>$me->accuracy,
                    'accuracy_symbol'=>$me->accuracy_symbol,
                    'traceability_ref_no'=>$me->traceability_ref_no,
                    'traceability_symbol'=>$me->traceability_symbol,
                    'cal_due_date'=>$expire,
                ]);

                // UPDATING RENEWAL STATUS
                $me->update(['renewed' => 1]);
            return ['status'=>true, 'data'=>$newMe];
        } catch (\Throwable $th) {
            return ['status'=>false, 'error'=>$th->getMessage()];
        }
    }

    // RELATIONS

    protected function getRangeWithUnitAttribute()
    {
        return $this->range.' '.$this->range_symbol;
    }

    protected function getAccuracyWithUnitAttribute()
    {
        return $this->accuracy.' '.$this->accuracy_symbol;
    }

    protected function getTraceabilityWithUnitAttribute()
    {
        return $this->traceability_ref_no.' '.$this->traceability_symbol;
    }
}
