<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Carbon\Carbon;

class PerformanceQualificationCertificate extends Model
{
    use HasFactory;

    protected $guarded = [];

    public function renew(int $pqId)
    {
        try {
            $pqc = $this->cloneCertificate($pqId);
            if ($pqc['status']) return ['status' => true, 'data'=>$pqc['data']];
            return ['status'=>false, ['error'=>$pqc]];
        } catch (\Throwable $th) {
            return ['status'=>false, 'error'=>$th->getMessage()];
        }
    }

    public function cloneCertificate($pqId)
    {
        $pqc = $this->with('user')->find($pqId);
        
        // MODIFYING DATE
        $expire = Carbon::createFromFormat('d-m-y', $pqc->next_due_date);
        $expire = $expire->addYear()->format('Y-m-d');

        // CLONING
        try {
            $newPqc = $this->create(
                [
                    'user_id'=>$pqc->user_id,
                    'performance_qualification_protocol_no'=>$pqc->performance_qualification_protocol_no,
                    'equipment_id'=>$pqc->equipment_id,
                    'equipment_system_utility'=>$pqc->equipment_system_utility,
                    'use_purpose'=>$pqc->use_purpose,
                    'make_model'=>$pqc->make_model,
                    'location'=>$pqc->location,
                    'name_of_test'=>$pqc->name_of_test,
                    'performance_qualification_test_date'=>$pqc->performance_qualification_test_date,
                    'next_due_date'=>$expire,
                    'validated_by'=>$pqc->validated_by,
                    'signature'=>$pqc->signature,
                ]);

                // UPDATING RENEWAL STATUS
                $pqc->update(['renewed' => 1]);
            return ['status'=>true, 'data'=>$newPqc];
        } catch (\Throwable $th) {
            return ['status'=>false, 'error'=>$th->getMessage()];
        }
    }

    // RELATIONS
    public function user()
    {
        return $this->belongsTo(CalibrationLabel::class, 'user_id', 'id');
    }

    // ACCESSOR
    protected function performanceQualificationTestDate(): Attribute
    {
        return Attribute::make(
            get: fn ($value) => Carbon::parse($value)->format('d-m-y'),
        );
    }

    protected function nextDueDate(): Attribute
    {
        return Attribute::make(
            get: fn ($value) => Carbon::parse($value)->format('d-m-y'),
        );
    }
}
