<?php

use App\Http\Controllers\NotesController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\UserController;


// ARTISAN COMMANDS
Route::get('command/{command}', [App\Http\Controllers\AdminController::class, 'command'])->name('admin_command');

Route::get('/', [App\Http\Controllers\AdminController::class, 'login'])->name('admin_login');
Route::group(['prefix' => 'admin', 'middleware' => 'admin.guest'], function () 
{
    Route::post('login/process', [App\Http\Controllers\AdminController::class, 'loginProcess'])->name('admin_login_process');
    Route::get('forget/process', [App\Http\Controllers\AdminController::class, 'forgetPwdProcess'])->name('admin_forget_process')->middleware(['throttle:forgetMail']);
    Route::get('reset', [App\Http\Controllers\AdminController::class, 'resetPwd'])->name('admin_reset');
    Route::post('reset/process/{token}', [App\Http\Controllers\AdminController::class, 'resetPwdProcess'])->name('admin_reset_process');
});

Route::group(['prefix' => 'admin', 'middleware' => 'admin.auth'], function () 
{
    Route::get('dashboard', [App\Http\Controllers\AdminController::class, 'index'])->name('admin_index');
    Route::get('logout', [App\Http\Controllers\AdminController::class, 'logout'])->name('admin_logout');

    // PDF
    Route::get('/pdf', [\App\Http\Controllers\PdfController::class, 'index'])->name('admin_pdf');
    // Route::get('/pdf/performance_qualification_certificate/{id}', [\App\Http\Controllers\PdfController::class, 'performanceQualificationCertificatePdf'])->name('admin_pdf_performance_qualification_certificate');
    Route::get('/pdf/download/{id}', [\App\Http\Controllers\PdfController::class, 'downloadPdf'])->name('admin_calibration_pdf_download');
    Route::get('pqcertificate/pdf/download/{id}', [\App\Http\Controllers\PdfController::class, 'performanceQualificationCertificatePdfDownload'])->name('pq.pdf.download');
    
    // LABEL PDF
    Route::get('pdf/label/{id}', [\App\Http\Controllers\PdfController::class, 'label'])->name('admin_pdf_label');
    
    // CERTIFICATE OF CALIBRATION
    // API
    Route::get('/certificate_of_calibrations', [\App\Http\Controllers\CalibrationController::class, 'indexApi'])->name('calibration.index.api');

    Route::get('/certificate_of_calibration', [\App\Http\Controllers\CalibrationController::class, 'index'])->name('admin_calibration_index');
    Route::get('/certificate_of_calibration/store', [\App\Http\Controllers\CalibrationController::class, 'store'])->name('admin_calibration_store');
    Route::post('/certificate_of_calibration/store/process', [\App\Http\Controllers\CalibrationController::class, 'storeProcess'])->name('admin_calibration_store_process');
    Route::get('/certificate_of_calibration/update/{id}', [\App\Http\Controllers\CalibrationController::class, 'update'])->name('admin_calibration_update');
    Route::post('/certificate_of_calibration/update/process/{id}', [\App\Http\Controllers\CalibrationController::class, 'updateProcess'])->name('admin_calibration_update_process');
    Route::get('/certificate_of_calibration/delete/{id}', [\App\Http\Controllers\CalibrationController::class, 'delete'])->name('admin_calibration_delete');
    Route::post('/certificate_of_calibration/downloads', [\App\Http\Controllers\CalibrationController::class, 'downloadMultiple'])->name('downloadMultiple');
    Route::get('/certificate_of_calibration/renew/{calibrationId}', [\App\Http\Controllers\CalibrationController::class, 'renew'])->name('calibration.renew');

    // MASTER EQUIPMENT
    Route::get('/master_equipment', [\App\Http\Controllers\MasterEquipmentController::class, 'index'])->name('admin_master_equipment_index');
    Route::get('/master_equipment/store', [\App\Http\Controllers\MasterEquipmentController::class, 'store'])->name('admin_master_equipment_store');
    Route::post('/master_equipment/store/process', [\App\Http\Controllers\MasterEquipmentController::class, 'storeProcess'])->name('admin_master_equipment_store_process');
    Route::get('/master_equipment/update/{id}', [\App\Http\Controllers\MasterEquipmentController::class, 'update'])->name('admin_master_equipment_update');
    Route::post('/master_equipment/update/process/{id}', [\App\Http\Controllers\MasterEquipmentController::class, 'updateProcess'])->name('admin_master_equipment_update_process');
    Route::get('/master_equipment/delete/{id}', [\App\Http\Controllers\MasterEquipmentController::class, 'delete'])->name('admin_master_equipment_delete');

    // MASTER EQUIPMENT EXPIRE
    Route::resource('/me_expires', 'App\Http\Controllers\MEExpireController');

    // PERFORMANCE QUALITY CERTIFICATE
    Route::get('/performance_quality_certificate', [\App\Http\Controllers\PerformanceQualificationCertificateController::class, 'index'])->name('admin_performance_quality_certificate_index');
    Route::get('/performance_quality_certificate/store', [\App\Http\Controllers\PerformanceQualificationCertificateController::class, 'store'])->name('admin_performance_quality_certificate_store');
    Route::post('/performance_quality_certificate/store/process', [\App\Http\Controllers\PerformanceQualificationCertificateController::class, 'storeProcess'])->name('admin_performance_quality_certificate_store_process');
    Route::get('/performance_quality_certificate/update/{id}', [\App\Http\Controllers\PerformanceQualificationCertificateController::class, 'update'])->name('admin_performance_quality_certificate_update');
    Route::post('/performance_quality_certificate/update/process/{id}', [\App\Http\Controllers\PerformanceQualificationCertificateController::class, 'updateProcess'])->name('admin_performance_quality_certificate_update_process');
    Route::get('/performance_quality_certificate/delete/{id}', [\App\Http\Controllers\PerformanceQualificationCertificateController::class, 'delete'])->name('admin_performance_quality_certificate_delete');
    
    // PERFORMANCE QUALITY CERTIFICATE EXPIRE
    Route::resource('/pqc_expires', 'App\Http\Controllers\PQCExpireController');

    // CUSTOMER
    Route::get('/customers', [\App\Http\Controllers\CustomerController::class, 'index'])->name('admin_customer_index');
    Route::get('/customers/store', [\App\Http\Controllers\CustomerController::class, 'store'])->name('admin_customer_store');
    Route::post('/customers/store/process', [\App\Http\Controllers\CustomerController::class, 'storeProcess'])->name('admin_customer_store_process');
    Route::get('/customers/update/{id}', [\App\Http\Controllers\CustomerController::class, 'update'])->name('admin_customer_update');
    Route::post('/customers/update/process/{id}', [\App\Http\Controllers\CustomerController::class, 'updateProcess'])->name('admin_customer_update_process');
    Route::get('/customers/delete/{id}', [\App\Http\Controllers\CustomerController::class, 'delete'])->name('admin_customer_delete');

    // INSTRUMENT
    Route::get('/instruments', [\App\Http\Controllers\InstrumentController::class, 'index'])->name('admin_instrument_index');
    Route::get('/instruments/store', [\App\Http\Controllers\InstrumentController::class, 'store'])->name('admin_instrument_store');
    Route::post('/instruments/store/process', [\App\Http\Controllers\InstrumentController::class, 'storeProcess'])->name('admin_instrument_store_process');
    Route::get('/instruments/update/{id}', [\App\Http\Controllers\InstrumentController::class, 'update'])->name('admin_instrument_update');
    Route::post('/instruments/update/process/{id}', [\App\Http\Controllers\InstrumentController::class, 'updateProcess'])->name('admin_instrument_update_process');
    Route::get('/instruments/delete/{id}', [\App\Http\Controllers\InstrumentController::class, 'delete'])->name('admin_instrument_delete');

    // UNIT SYMBOLS
    Route::get('/unit_symbols', [\App\Http\Controllers\UnitSymbolController::class, 'index'])->name('admin_unit_symbol_index');
    Route::get('/unit_symbols/store', [\App\Http\Controllers\UnitSymbolController::class, 'store'])->name('admin_unit_symbol_store');
    Route::post('/unit_symbols/store/process', [\App\Http\Controllers\UnitSymbolController::class, 'storeProcess'])->name('admin_unit_symbol_store_process');
    Route::get('/unit_symbols/update/{id}', [\App\Http\Controllers\UnitSymbolController::class, 'update'])->name('admin_unit_symbol_update');
    Route::post('/unit_symbols/update/process/{id}', [\App\Http\Controllers\UnitSymbolController::class, 'updateProcess'])->name('admin_unit_symbol_update_process');
    Route::get('/unit_symbols/delete/{id}', [\App\Http\Controllers\UnitSymbolController::class, 'delete'])->name('admin_unit_symbol_delete');

    // CALIBRATION EXPIRE
    Route::get('/calibration_expire', [\App\Http\Controllers\CalibrationExpireController::class, 'index'])->name('admin_calibration_expire_index');
    Route::get('/calibration_expire/mail/{id}/{email?}', [\App\Http\Controllers\CalibrationExpireController::class, 'email'])->name('admin_calibration_expire_mail');
    Route::post('/calibration_expire/mail/process/{id}', [\App\Http\Controllers\CalibrationExpireController::class, 'sendMail'])->name('admin_calibration_expire_mail_process');

    // CUSTOMER API
    Route::get('/api/customer/', [\App\Http\Controllers\CustomerController::class, 'show'])->name('admin_customer_show');
    
    //USER API
    Route::get('/api/user_data', [\App\Http\Controllers\NewQrCodeController::class,'get_dates'])->name('admin_user_date');
    
    // CALIBRATION LABEL
    Route::get('calibrations/label/delete/{label}', [\App\Http\Controllers\CalibrationLabelController::class, 'delete'])->name('label.delete');
    Route::get('calibrations/labels/export', [\App\Http\Controllers\CalibrationLabelController::class, 'export'])->name('label.export');
    Route::resource('calibrations/label', '\App\Http\Controllers\CalibrationLabelController');
    
    // QR Codes
    
    Route::resource('qrcode', \App\Http\Controllers\NewQrCodeController::class);
        Route::get('qrcode/delete/{id}', [\App\Http\Controllers\NewQrCodeController::class,'delete'])->name('qrcode.delete');


    Route::get('renew/{qrcode}', [\App\Http\Controllers\NewQrCodeController::class,'renew'])->name('qrcode.renew');
    Route::get('expire', [\App\Http\Controllers\NewQrCodeController::class,'expire'])->name('qrcode.expire');
    Route::get('searchby', [\App\Http\Controllers\NewQrCodeController::class, 'search'])->name('qrcode.search');
    Route::post('MultiQRDelete',[\App\Http\Controllers\NewQrCodeController::class,'multiQrDelete'])->name('qrcode.multidelete');

    


    Route::resource('role',RoleController::class);
    Route::resource('note',NotesController::class);
    Route::resource('user',UserController::class);
    Route::post('updateTime',[NotesController::class,'updateTime'])->name('updateTime');
    Route::get('filedelete/{id}',[NotesController::class,'filedelete'])->name('file.delete');
    Route::get('audiodelete/{id}',[NotesController::class,'audiodelete'])->name('audio.delete');


});
Route::get('pdf/show_by_label/{label}', [\App\Http\Controllers\PdfController::class, 'showByLabel'])->name('pdf.showByLabel');
Route::get('/pdf/performance_qualification_certificate/{id}', [\App\Http\Controllers\PdfController::class, 'performanceQualificationCertificatePdf'])->name('admin_pdf_performance_qualification_certificate');

// UNIVERSAL LINK
Route::get('pdf/show/{id}', [\App\Http\Controllers\PdfController::class, 'show'])->name('pdf_show');